@@ -1,4 +1,4 @@
-# Copyrights 2011 by Mark Overmeer.
+# Copyrights 2011-2012 by Mark Overmeer.
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.00.
@@ -7,7 +7,7 @@ use strict;
 
 package POSIX::3;
 use vars '$VERSION';
-$VERSION = '0.08';
+$VERSION = '0.09';
 
 
 use Carp qw/croak/;
@@ -154,7 +154,7 @@ sub posix_1003_names(@)
 
     foreach my $pkg (@modules)
     {   eval "require $pkg";
-        $@ && die $@;
+        $@ && next;  # die?
         $pkg->can('import') or next;
         $pkg->import(':none');   # create %EXPORT_OK
 
